/**
 * Document
 */
export function document(nodes) {
    return {
        document: {
            object: 'document',
            nodes,
            data: {},
        },
    };
}
export function markdown(markdown) {
    return {
        markdown,
    };
}
/**
 * Blocks
 */
export const paragraph = blockFactory('paragraph');
export const heading1 = blockFactory('heading-1');
export const heading2 = blockFactory('heading-2');
export const heading3 = blockFactory('heading-3');
export const listOrdered = blockFactory('list-ordered');
export const listUnordered = blockFactory('list-unordered');
export const listTasks = blockFactory('list-tasks');
export const quote = blockFactory('blockquote');
export const hint = blockFactory('hint');
export const images = blockFactory('images');
export const divider = voidBlockFactory('divider');
export const file = voidBlockFactory('file');
export const openapi = voidBlockFactory('swagger');
export const openapiOperation = voidBlockFactory('openapi-operation');
/**
 * Code blocks.
 */
export const codeblockLine = blockFactory('code-line');
export function codeblock(nodes, data = {}) {
    return {
        object: 'block',
        type: 'code',
        nodes: typeof nodes === 'string'
            ? nodes.split('\n').map((line) => codeblockLine(text(line)))
            : nodes,
        data,
    };
}
/**
 * Text
 */
export function text(text) {
    return {
        object: 'text',
        leaves: typeof text === 'string' ? [textLeaf(text)] : text,
    };
}
export function textLeaf(text, marks) {
    return {
        object: 'leaf',
        text,
        marks: marks ?? [],
    };
}
/**
 * Marks
 */
export function bold() {
    return {
        object: 'mark',
        type: 'bold',
    };
}
export function italic() {
    return {
        object: 'mark',
        type: 'italic',
    };
}
export function code() {
    return {
        object: 'mark',
        type: 'code',
    };
}
export function keyboard() {
    return {
        object: 'mark',
        type: 'keyboard',
    };
}
export function strikethrough() {
    return {
        object: 'mark',
        type: 'strikethrough',
    };
}
export function color(data) {
    return {
        object: 'mark',
        type: 'color',
        data,
    };
}
/**
 * Factories
 */
function blockFactory(type) {
    // @ts-ignore
    return (nodes, data = {}) => ({
        object: 'block',
        type,
        nodes: Array.isArray(nodes) ? nodes : [nodes],
        data,
    });
}
function voidBlockFactory(type) {
    // @ts-ignore
    return (data) => ({
        object: 'block',
        isVoid: true,
        type,
        data,
    });
}
